from django.contrib import admin
from models import Testimonial, TestimonialProduct

class TestimonialProductAdmin(admin.ModelAdmin):
    pass
admin.site.register(TestimonialProduct, TestimonialProductAdmin)

class TestimonialAdmin(admin.ModelAdmin):
    ### List display
    list_display = (
        'author',
        'product',
        'published',
        )
    list_editable = [
        'published',
        ]
    search_fields = [
        'author',
        'testimony',
        ]
    list_filter = [
        'published',
        ]
    #date_hierarchy = 'created'
    list_per_page = 100
    list_select_related = True

    ### Record display
    fieldsets = (
        ('General', {
            #'classes': ('collapse',),
            'description': 'General',
            'fields': (
                'author',
                'testimony',
                'product',
           )}),
        ('Admin', {
            #'classes': ('collapse',),
            'description': 'Publishing information bits.',
            'fields': (
                'published',
           )}),
        )
    #readonly_fields = ['date_given']
admin.site.register(Testimonial, TestimonialAdmin)






# -*- coding: utf-8 -*-
from south.utils import datetime_utils as datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'TestimonialProduct'
        db.create_table(u'testimony_testimonialproduct', (
            (u'id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=100)),
        ))
        db.send_create_signal(u'testimony', ['TestimonialProduct'])

        # Adding field 'TestimonialPlugin.product'
        db.add_column(u'cmsplugin_testimonialplugin', 'product',
                      self.gf('django.db.models.fields.related.ForeignKey')(to=orm['testimony.TestimonialProduct'], null=True, blank=True),
                      keep_default=False)

        # Deleting field 'Testimonial.company'
        db.delete_column(u'testimony_testimonial', 'company')

        # Deleting field 'Testimonial.position'
        db.delete_column(u'testimony_testimonial', 'position')

        # Adding field 'Testimonial.product'
        db.add_column(u'testimony_testimonial', 'product',
                      self.gf('django.db.models.fields.related.ForeignKey')(to=orm['testimony.TestimonialProduct'], null=True, blank=True),
                      keep_default=False)


    def backwards(self, orm):
        # Deleting model 'TestimonialProduct'
        db.delete_table(u'testimony_testimonialproduct')

        # Deleting field 'TestimonialPlugin.product'
        db.delete_column(u'cmsplugin_testimonialplugin', 'product_id')


        # User chose to not deal with backwards NULL issues for 'Testimonial.company'
        raise RuntimeError("Cannot reverse this migration. 'Testimonial.company' and its values cannot be restored.")
        
        # The following code is provided here to aid in writing a correct migration        # Adding field 'Testimonial.company'
        db.add_column(u'testimony_testimonial', 'company',
                      self.gf('django.db.models.fields.CharField')(max_length=100),
                      keep_default=False)

        # Adding field 'Testimonial.position'
        db.add_column(u'testimony_testimonial', 'position',
                      self.gf('django.db.models.fields.CharField')(max_length=100, null=True, blank=True),
                      keep_default=False)

        # Deleting field 'Testimonial.product'
        db.delete_column(u'testimony_testimonial', 'product_id')


    models = {
        'cms.cmsplugin': {
            'Meta': {'object_name': 'CMSPlugin'},
            'changed_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language': ('django.db.models.fields.CharField', [], {'max_length': '15', 'db_index': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.CMSPlugin']", 'null': 'True', 'blank': 'True'}),
            'placeholder': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.Placeholder']", 'null': 'True'}),
            'plugin_type': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'}),
            'position': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'cms.placeholder': {
            'Meta': {'object_name': 'Placeholder'},
            'default_width': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slot': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'})
        },
        u'testimony.testimonial': {
            'Meta': {'ordering': "['author']", 'object_name': 'Testimonial'},
            'author': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['testimony.TestimonialProduct']", 'null': 'True', 'blank': 'True'}),
            'published': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'testimony': ('django.db.models.fields.TextField', [], {})
        },
        u'testimony.testimonialplugin': {
            'Meta': {'object_name': 'TestimonialPlugin', 'db_table': "u'cmsplugin_testimonialplugin'", '_ormbases': ['cms.CMSPlugin']},
            'block': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            u'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['cms.CMSPlugin']", 'unique': 'True', 'primary_key': 'True'}),
            'list_type': ('django.db.models.fields.CharField', [], {'default': "'random'", 'max_length': '10'}),
            'product': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['testimony.TestimonialProduct']", 'null': 'True', 'blank': 'True'}),
            'size': ('django.db.models.fields.IntegerField', [], {}),
            'template_path': ('django.db.models.fields.CharField', [], {'default': "('testimony/list_default.html', 'Default list (stationary)')", 'max_length': '100'})
        },
        u'testimony.testimonialproduct': {
            'Meta': {'ordering': "['name']", 'object_name': 'TestimonialProduct'},
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        }
    }

    complete_apps = ['testimony']


from django.conf import settings
gettext = lambda s: s

TESTIMONY_TEMPLATES = getattr(settings, 'TESTIMONY_TEMPLATES',
    (
        ('testimony/list_default.html', gettext('Default list (stationary)')),
        ('testimony/rotator.html', gettext('Continuous scroll (animated)')),
        ('testimony/vticker.html', gettext('Scroll and pause (animated)')),
    )
)




from django.forms import widgets, ModelForm, Form, CharField, EmailField, TextInput, DecimalField, Textarea, IntegerField, DateField, TimeField, Select
from django.shortcuts import HttpResponseRedirect
from django.core.urlresolvers import reverse
from django.core.mail import EmailMessage, get_connection
from django.template.loader import render_to_string
from django.contrib.localflavor.us.forms import USPhoneNumberField, USStateField, USZipCodeField, USStateSelect
from django.forms.extras.widgets import SelectDateWidget
import datetime
from django.template import Template, Context
from django.conf import settings  
from models import Testimonial



def sendEMail(self, site_email, body=None, subject=None, replyto=None):
    headers = {}
    
    if not body:
        format = ""
        for key in self.cleaned_data.keys():
            format += "%s: {{ %s }}\n" % (key, key)
        t = Template(format)
        body = t.render(Context(self.cleaned_data))
    
    if not subject:
        subject = 'Website feedback'
        
    if replyto:
        headers['Reply-To'] = replyto
        
    email_message = EmailMessage(
                                subject=subject,
                                body=body,
                                #from_email=site_email,
                                to=[site_email],
                                #connection=connection,
                                headers=headers,
                                #cc=['',]
                                )    

    ret = email_message.send(fail_silently=True)
    print ret


class TestimonialForm(ModelForm):
    
    class Meta:
        model = Testimonial
        exclude = ('date_given','published',)   

    def __init__(self, *args, **kwargs):
        super(TestimonialForm, self).__init__(*args, **kwargs)
                
        self.fields['author'].widget.attrs={'size':'51',} 
        self.fields['author'].label = "Your Name"
        self.fields['email'].widget.attrs={'size':'51',} 
        self.fields['email'].label = "Your email" 
        self.fields['poster_ip'].widget = widgets.HiddenInput()
        
    def save(self, *args, **kwargs):
        commit = kwargs.pop('commit', True)
        ip_address = kwargs.pop('ip_address', None)
        site_email = kwargs.pop('site_email', None)

        testimonial = super(TestimonialForm, self).save(commit=False)

        if ip_address:
            testimonial.poster_ip=ip_address
        
        if commit:
            testimonial.save()
        
            body = render_to_string("email_feedback.txt", {
                                                   'data': self.cleaned_data,
                                                   })
            subject = "SITE TESTIMONIAL"
            replyto = self.cleaned_data['email']
            sendEMail(self, site_email, body=body, subject=subject, replyto=replyto)

        
        return testimonial
    



from django.utils.translation import ugettext_lazy as _
from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from models import Testimonial, TestimonialPlugin as TestimonialPluginModel


class TestimonialPlugin(CMSPluginBase):
    module = "Oddotter"
    model = TestimonialPluginModel
    name = _("Testimonials Listing")
    render_template = "testimony/plugin.html"
    text_enabled = True
    admin_preview = False
    fieldsets = (
        (None, {
            'fields': (
                'block',
                ('size', 'product'),
                ('list_type','template_path',),
        )}),
    )

    def render(self, context, instance, placeholder):
        list_type = instance.list_type or 0

        testimonials = Testimonial.objects.all().filter(published=True)
        if instance.product:
            testimonials = testimonials.filter(product=instance.product)
        testimonials = testimonials.order_by('?')

        max = instance.size
        if max > testimonials.count():
            max = testimonials.count()

        context.update({'testimonials':testimonials[:max],})
        context.update({'instance': instance,})
        context.update({'content': instance.render(context),})

        return context

plugin_pool.register_plugin(TestimonialPlugin)




    




from django.db import models
from django.core.exceptions import ValidationError
from django.template import TemplateSyntaxError, TemplateDoesNotExist, loader
from django.utils.translation import ugettext_lazy as _
from cms.models import CMSPlugin
import settings


class TestimonialProduct(models.Model):
    name = models.CharField(_("product name"), max_length=100)

    def __unicode__(self):
        return self.name

    class Meta:
        verbose_name = _('product')
        verbose_name_plural = _('products')
        ordering = ["name"]

class Testimonial(models.Model):
    author = models.CharField(_("author's name"), max_length=100)
    testimony = models.TextField(_("testimonial"), help_text='Describe your experience with us')
    published = models.BooleanField(_('published'), default=False, help_text='publish this testimonial to the public')
    product = models.ForeignKey(TestimonialProduct, blank=True, null=True)

    def __unicode__(self):
        return self.author

    class Meta:
        verbose_name = _('testimony')
        verbose_name_plural = _('testimonies')
        ordering = ["author"]



LIST_TYPE_CHOICES = (
        ('random', 'random'),
    )    
class TestimonialPlugin(CMSPlugin):
	
    block = models.CharField(_('Title'), max_length=200)
    size = models.IntegerField(_('size'), help_text='number of testimonials to show in this block')
    list_type = models.CharField(_('list type'), max_length=10, choices=LIST_TYPE_CHOICES, default=LIST_TYPE_CHOICES[0][0])
    product = models.ForeignKey(TestimonialProduct, blank=True, null=True, help_text="(chose nothing to select from all categories")
    template_path = models.CharField(_("Template"), max_length=100, choices=settings.TESTIMONY_TEMPLATES, default=settings.TESTIMONY_TEMPLATES[0],
        help_text=_('Enter a template (i.e. "testimony/list_default.html") which will be rendered.'))

    def __unicode__(self):
        return self.block
    
    def get_template(self):
        template_path = self.template_path or "testimony/list_default.html"
        try:
           testimonial_template = loader.get_template(template_path)
        except (TemplateSyntaxError, TemplateDoesNotExist), e:
            raise ValidationError(str(e))
       
        return testimonial_template
        
    def render(self, context):
        return self.get_template().render(context)



#!/usr/bin/env python
from setuptools import setup, find_packages

version = __import__('testimony').get_version()

install_requires = [
    'Django>=1.4',
    'django-cms>=2.3.5',
]

dependency_links = []

setup(
    name = "django-testimony",
    version = version,
    url = 'https://bitbucket.org/oddotterco/django-testimony',
    license = 'BSD',
    platforms=['Linux'],
    description = "A Django app that will create a pluggable django-cms testimony form and content plugin within your project..",
    keywords='django, cms, theme',
    author = "Odd Otter Co",
    author_email = 'testimony@oddotter.com',
    packages = find_packages(),
    install_requires = install_requires,
    dependency_links = dependency_links,
    include_package_data = True,
    zip_safe = False,
    classifiers = [
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    package_dir = {
        'testimony': 'testimony',
    },
)
